agde

Struct Capabilities

source
pub struct Capabilities { /* private fields */ }
Describes the capabilities and properties of the client. Sent in the initial Message exchange.

Implementations

source

impl Capabilities

source

pub fn new(uuid: Uuid, persistent: bool, help_desire: i16) -> Self

Creates a new set of capabilities and properties used by this client.

See the various getters for more information about the usage of these options.

source

pub fn version(&self) -> &Version

Version of this client.

source

pub fn